@@ -23,7 +23,6 @@
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QDebug>
-#include <QQmlEngine>
 
 // Frameworks
 #include <KConfigGroup>
@@ -33,16 +32,12 @@
 // Own
 #include "view.h"
 
-static const char description[] = I18N_NOOP("Cuttlefish Icon Browser");
-static const char version[] = PROJECT_VERSION;
-static const char HOME_URL[] = "http://kde.org";
-
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("cuttlefish");
 
-    app.setApplicationVersion(version);
+    app.setApplicationVersion(PROJECT_VERSION);
 
     const static auto _category = QStringLiteral("category");
     QCommandLineOption category = QCommandLineOption(QStringList() << QStringLiteral("c") << _category,
@@ -58,7 +53,7 @@ int main(int argc, char **argv)
 
     QCommandLineParser parser;
     parser.addVersionOption();
-    parser.setApplicationDescription(description);
+    parser.setApplicationDescription("Cuttlefish Icon Browser");
     parser.addHelpOption();
     parser.addOption(category);
     parser.addOption(fullscreen);
@@ -69,8 +64,6 @@ int main(int argc, char **argv)
     QString _cc = parser.value(category);
 
     auto settingsapp = new CuttleFish::View(_cc, parser);
-    QObject::connect(settingsapp->engine(), &QQmlEngine::quit, &app, &QApplication::quit);
-
     if (parser.isSet(fullscreen)) {
         settingsapp->setVisibility(QWindow::FullScreen);
     }
